/*

    * This file is a part of Libcsys.
    * Library for managing drive and getting system resource information in real time for CuboCore Application Suite
	* Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, vsit http://www.gnu.org/licenses/.
    *
*/


#ifndef CPUINFO_H
#define CPUINFO_H

#include "libcsys_global.h"

//#define PROC_CPUINFO "/proc/cpuinfo"
//#define PROC_LOADAVG "/proc/loadavg"
//#define PROC_STAT    "/proc/stat"

const QString PROC_CPUINFO = "/proc/cpuinfo";
const QString PROC_LOADAVG = "/proc/loadavg";
const QString PROC_STAT    = "/proc/stat";

class CpuTimes {

	public:
		CpuTimes() {
			mTotal = 0;
			mIdle = 0;
		};

		CpuTimes( QString cpuTimes ) {
			/*  user nice system idle iowait  irq  softirq steal guest guest_nice
			   cpu  4705 356  584    3699   23    23     0       0     0      0			<<=== Remove this line and use
				.
			   cpuN 4705 356  584    3699   23    23     0       0     0      0

				 The meanings of the columns are as follows, from left to right:
					- user: normal processes executing in user mode
					- nice: niced processes executing in user mode
					- system: processes executing in kernel mode
					- idle: twiddling thumbs
					- iowait: waiting for I/O to complete
					- irq: servicing interrupts
					- softirq: servicing softirqs
					- steal: involuntary wait
					- guest: running a normal guest
					- guest_nice: running a niced guest
			   */

			QList<qreal> times;
			QStringList timesList = cpuTimes.trimmed().split( QRegExp( "\\s" ), QString::SkipEmptyParts );
			for( int i = 1; i < timesList.count(); i++ )
				times << timesList.at( i ).toDouble();

			if ( times.count() >= 8 ) {
				mTotal = times[ 0 ] + times[ 1 ] + times[ 2 ] + times[ 3 ] + times[ 4 ] + times[ 5 ] + times[ 6 ] + times[ 7 ];
				mIdle = times[ 3 ] + times[ 4 ];
			}
		}

		qreal total() {

			return mTotal;
		};

		qreal idle() {

			return mIdle;
		};

	private:
		qreal mTotal = 0;
		qreal mIdle = 0;
};

class LIBCSYSSHARED_EXPORT CpuInfo : public QObject {
	Q_OBJECT

	public:
		static CpuInfo* instance();

		quint8 getCpuCoreCount() const;
		QList<int> getCpuPercents() const;
		QList<double> getLoadAvgs() const;

	private:
		/* Init */
		CpuInfo();

		static CpuInfo *info;

		QList<int> mCpuPercents;
		QList<double> mLoadAvgs = { 0, 0, 0 };

		QBasicTimer readTimer;

		QHash<int, CpuTimes> lastRead;
		QHash<int, CpuTimes> thisRead;

	protected:
		void timerEvent( QTimerEvent *tEvent );
};

#endif // CPUINFO_H
