/*
    
    * This file is a part of Libcsys.
    * Library for managing drive and getting system resource information in real time for CuboCore Application Suite
	* Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, vsit http://www.gnu.org/licenses/.
    *
*/


#ifndef PROCESS_H
#define PROCESS_H

#include "libcsys_global.h"


class LIBCSYSSHARED_EXPORT Process {

public:
    pid_t getPid() const;
    void setPid( const pid_t &value );

    quint64 getRss() const;
    void setRss( const quint64 &value );

    double getPmem() const;
    void setPmem( const double &value );

    quint64 getVsize() const;
    void setVsize( const quint64 &value );

    QString getUname() const;
    void setUname( const QString &value );

    double getPcpu() const;
    void setPcpu( const double &value );

    QString getStartTime() const;
    void setStartTime( const QString &value );

    QString getState() const;
    void setState( const QString &value );

    QString getGroup() const;
    void setGroup( const QString &value );

    int getNice() const;
    void setNice( const int &value );

    QString getCpuTime() const;
    void setCpuTime( const QString &value );

    QString getSession() const;
    void setSession( const QString &value );

    QString getCmd() const;
    void setCmd( const QString &value );

private:
    pid_t pid;
    quint64 rss;
    double pmem, pcpu;
    quint64 vsize;
    int nice;
    QString cpuTime, session, cmd, startTime, state, group, uname;

};


#endif // PROCESS_H
